@@ -12,6 +12,10 @@
 #ifndef KUISERVERJOBTRACKER_P_H
 #define KUISERVERJOBTRACKER_P_H
 
+#include <kjobwidgets_export.h>
+
+#if KJOBWIDGETS_ENABLE_DEPRECATED_SINCE(6, 17)
+
 #include <memory>
 
 #include <QDBusServiceWatcher>
@@ -39,4 +43,6 @@ private:
     std::unique_ptr<QDBusServiceWatcher> m_watcher;
 };
 
+#endif // KJOBWIDGETS_DEPRECATED_WARNINGS_SINCE
+
 #endif
